aboutsummaryrefslogtreecommitdiff
path: root/src/argaze.test/GazeFeatures.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/argaze.test/GazeFeatures.py')
-rw-r--r--src/argaze.test/GazeFeatures.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/argaze.test/GazeFeatures.py b/src/argaze.test/GazeFeatures.py
index a6709cb..d609dd2 100644
--- a/src/argaze.test/GazeFeatures.py
+++ b/src/argaze.test/GazeFeatures.py
@@ -631,8 +631,8 @@ class TestAOIScanPathClass(unittest.TestCase):
self.assertEqual(aoi_scan_path.get_letter_aoi('B'), 'Shu')
self.assertEqual(aoi_scan_path.get_letter_aoi('C'), 'Foo')
- # Check string representation
- self.assertEqual(str(aoi_scan_path), 'ABCA')
+ # Check letter sequence representation
+ self.assertEqual(aoi_scan_path.letter_sequence, 'ABCA')
def test_transition_matrix(self):
"""Test AOIScanPath transition matrix feature."""